# Environment Configuration for {{ project_name }}

# Django settings
SECRET_KEY=your-super-secret-key-here-change-this-in-production
DEBUG=True
ALLOWED_HOSTS=localhost,127.0.0.1

{% if config.use_postgresql %}
# Database settings
DB_NAME={{ project_name }}
DB_USER=postgres
DB_PASSWORD=your-db-password
DB_HOST=localhost
DB_PORT=5432
{% endif %}

{% if config.use_celery %}
# Celery settings
CELERY_BROKER_URL=redis://localhost:6379/0
CELERY_RESULT_BACKEND=redis://localhost:6379/0
{% endif %}

# Email settings
DEFAULT_FROM_EMAIL=noreply@{{ project_name }}.com

{% if config.email_provider == 'sendgrid' %}
# SendGrid
SENDGRID_API_KEY=your-sendgrid-api-key
{% elif config.email_provider == 'mailgun' %}
# Mailgun
MAILGUN_USERNAME=your-mailgun-username
MAILGUN_PASSWORD=your-mailgun-password
{% endif %}

{% if config.use_sentry %}
# Sentry
SENTRY_DSN=your-sentry-dsn-here
ENVIRONMENT=development
{% endif %}

{% if config.use_drf %}
# CORS settings
CORS_ALLOWED_ORIGINS=http://localhost:3000,http://127.0.0.1:3000
{% endif %}

{% if config.cloud_provider == 'aws' %}
# AWS settings
AWS_ACCESS_KEY_ID=your-aws-access-key
AWS_SECRET_ACCESS_KEY=your-aws-secret-key
AWS_STORAGE_BUCKET_NAME=your-s3-bucket-name
AWS_S3_REGION_NAME=us-east-1
{% elif config.cloud_provider == 'gcp' %}
# Google Cloud settings
GCS_BUCKET_NAME=your-gcs-bucket-name
GOOGLE_APPLICATION_CREDENTIALS=path/to/your/service-account-key.json
{% elif config.cloud_provider == 'azure' %}
# Azure settings
AZURE_ACCOUNT_NAME=your-storage-account-name
AZURE_ACCOUNT_KEY=your-storage-account-key
AZURE_CONTAINER=your-container-name
{% endif %}