{
  "name": "{{ project_name }}",
  "version": "1.0.0",
  "description": "Frontend build pipeline for {{ project_name }}",
  "main": "index.js",
  "scripts": {
    {% if config.frontend_pipeline == 'vite' %}
    "dev": "vite",
    "build": "vite build",
    "preview": "vite preview"
    {% elif config.frontend_pipeline == 'webpack' %}
    "dev": "webpack serve --mode=development",
    "build": "webpack --mode=production",
    "watch": "webpack --watch"
    {% elif config.frontend_pipeline == 'parcel' %}
    "dev": "parcel serve static/src/index.html",
    "build": "parcel build static/src/index.html --dist-dir static/dist"
    {% endif %}
  },
  "dependencies": {
    "htmx.org": "^1.9.8",
    "alpinejs": "^3.13.3",
    "hyperscript.org": "^0.9.12"
  },
  "devDependencies": {
    {% if config.frontend_pipeline == 'vite' %}
    "vite": "^5.0.0",
    "@vitejs/plugin-legacy": "^5.0.0",
    "terser": "^5.24.0"
    {% elif config.frontend_pipeline == 'webpack' %}
    "webpack": "^5.89.0",
    "webpack-cli": "^5.1.4",
    "webpack-dev-server": "^4.15.1",
    "css-loader": "^6.8.1",
    "style-loader": "^3.3.3",
    "mini-css-extract-plugin": "^2.7.6",
    "html-webpack-plugin": "^5.5.3"
    {% elif config.frontend_pipeline == 'parcel' %}
    "parcel": "^2.10.0",
    "@parcel/transformer-sass": "^2.10.0"
    {% endif %}
  },
  "keywords": [
    "django",
    "htmx",
    "alpinejs",
    "tailwindcss"
  ],
  "author": "",
  "license": "MIT"
}