# Base requirements for {{ project_name }}
Django==5.1.5
{% if config.use_postgresql %}
psycopg2-binary==2.9.10
{% endif %}

# Core dependencies
python-decouple==3.8
Pillow==11.0.0

# Authentication
django-allauth==65.3.0

# Forms and widgets
django-widget-tweaks==1.5.0

{% if config.use_drf %}
# Django REST Framework
djangorestframework==3.15.2
django-cors-headers==4.6.0
{% endif %}

{% if config.use_celery %}
# Background tasks
celery==5.4.0
redis==5.2.1
django-celery-beat==2.8.0
django-celery-results==2.5.1
{% endif %}

{% if config.use_sentry %}
# Error tracking
sentry-sdk==2.21.0
{% endif %}

# Utilities
python-dotenv==1.0.1