# Git
.git
.gitignore

# Python
__pycache__
*.pyc
*.pyo
*.pyd
*.so
.Python
env
venv
ENV
venv.bak
pip-log.txt
pip-delete-this-directory.txt
.tox
.coverage
.pytest_cache
htmlcov

# Django
*.log
local_settings.py
db.sqlite3
media

# Node.js
{% if config.frontend_pipeline != 'none' %}
node_modules
npm-debug.log
{% endif %}

# IDE
.vscode
.idea
*.swp
*.swo

# OS
.DS_Store
.DS_Store?
._*
.Spotlight-V100
.Trashes
ehthumbs.db
Thumbs.db

# Development files
.env
.env.local
README.md
Dockerfile
docker-compose.yml