# Production requirements
-r base.txt

# Production server
gunicorn==23.0.0

# Production utilities
whitenoise==6.8.2

{% if config.cloud_provider == 'aws' %}
# AWS
boto3==1.35.95
django-storages==1.14.4
{% endif %}

{% if config.cloud_provider == 'gcp' %}
# Google Cloud
google-cloud-storage==2.18.2
django-storages==1.14.4
{% endif %}

{% if config.cloud_provider == 'azure' %}
# Azure
azure-storage-blob==12.24.0
django-storages==1.14.4
{% endif %}